@@ -4,7 +4,7 @@ Attean - A Semantic Web Framework
 
 =head1 VERSION
 
-This document describes Attean version 0.030_01	
+This document describes Attean version 0.031	
 
 =head1 SYNOPSIS
 
@@ -51,7 +51,7 @@ Semantic Web (RDF and SPARQL) data.
 package Attean {
 	use v5.14;
 	use warnings;
-	our $VERSION	= '0.030_02';
+	our $VERSION	= '0.031_01';
 	use Attean::API;
 	
 	use Attean::Blank;
@@ -429,6 +429,55 @@ currently undefined.
 		my @sorted	= sort { $media_types{$b} <=> $media_types{$a} } keys %media_types;
 		return join(',', @sorted);
 	}
+	
+	
+	our %global_functions;
+
+=item C<< register_global_function( %uri_to_func ) >>
+
+=cut
+	sub register_global_function {
+		my $class	= shift;
+		my %args	= @_;
+		foreach my $uri (keys %args) {
+			my $func	= $args{ $uri };
+			$global_functions{ $uri }	= $func;
+		}
+	}
+
+=item C<< get_global_function( $uri ) >>
+
+=cut
+	sub get_global_function {
+		my $class	= shift;
+		my $uri		= shift;
+		return $global_functions{ $uri };
+	}
+	
+	our %global_aggregates;
+
+=item C<< register_global_aggregate( %uri_to_hash ) >>
+
+=cut
+	sub register_global_aggregate {
+		my $class	= shift;
+		my %args	= @_;
+		foreach my $uri (keys %args) {
+			my $funcs	= $args{ $uri };
+			$global_aggregates{ $uri }	= $funcs;
+		}
+	}
+
+=item C<< get_global_aggregate( $uri ) >>
+
+=cut
+	sub get_global_aggregate {
+		my $class	= shift;
+		my $uri		= shift;
+		return $global_aggregates{ $uri };
+	}
+	
+	
 }
 
 1;
@@ -452,7 +501,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2020 Gregory Todd Williams.
+Copyright (c) 2014--2022 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
