@@ -7,7 +7,7 @@ Attean::Expression - SPARQL Expressions
 
 =head1 VERSION
 
-This document describes Attean::Expression version 0.030
+This document describes Attean::Expression version 0.031
 
 =head1 SYNOPSIS
 
@@ -40,7 +40,7 @@ use Attean::API::Expression;
 
 =cut
 
-package Attean::ValueExpression 0.030 {
+package Attean::ValueExpression 0.031 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	use AtteanX::SPARQL::Constants;
@@ -101,7 +101,7 @@ package Attean::ValueExpression 0.030 {
 
 =cut
 
-package Attean::UnaryExpression 0.030 {
+package Attean::UnaryExpression 0.031 {
 	use Moo;
 	use Types::Standard qw(Enum);
 	use namespace::clean;
@@ -138,7 +138,7 @@ package Attean::UnaryExpression 0.030 {
 
 =cut
 
-package Attean::BinaryExpression 0.030 {
+package Attean::BinaryExpression 0.031 {
 	use Moo;
 	use Types::Standard qw(Enum);
 	use namespace::clean;
@@ -166,7 +166,7 @@ package Attean::BinaryExpression 0.030 {
 
 =cut
 
-package Attean::FunctionExpression 0.030 {
+package Attean::FunctionExpression 0.031 {
 	use Moo;
 	use Types::Standard qw(Enum ConsumerOf HashRef);
 	use Types::Common::String qw(UpperCaseStr);
@@ -230,9 +230,9 @@ package Attean::FunctionExpression 0.030 {
 	}
 }
 
-package Attean::AggregateExpression 0.030 {
+package Attean::AggregateExpression 0.031 {
 	use Moo;
-	use Types::Standard qw(Bool Enum Str HashRef ConsumerOf);
+	use Types::Standard qw(Bool Enum Str HashRef ConsumerOf Maybe);
 	use Types::Common::String qw(UpperCaseStr);
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -246,9 +246,10 @@ package Attean::AggregateExpression 0.030 {
 		return $args;
 	};
 	sub BUILD {
-		state $type	= Enum[qw(COUNT SUM MIN MAX AVG GROUP_CONCAT SAMPLE RANK)];
+		state $type	= Enum[qw(COUNT SUM MIN MAX AVG GROUP_CONCAT SAMPLE RANK CUSTOM)];
 		$type->assert_valid(shift->operator);
 	}
+	has 'custom_iri'	=> (is => 'ro', isa => Maybe[Str]);
 	has 'operator'		=> (is => 'ro', isa => UpperCaseStr, coerce => UpperCaseStr->coercion, required => 1);
 	has 'scalar_vars'	=> (is => 'ro', isa => HashRef, default => sub { +{} });
 	has 'distinct'		=> (is => 'ro', isa => Bool, default => 0);
@@ -298,7 +299,7 @@ package Attean::AggregateExpression 0.030 {
 	}
 }
 
-package Attean::CastExpression 0.030 {
+package Attean::CastExpression 0.031 {
 	use Moo;
 	use Types::Standard qw(Enum ConsumerOf);
 	use AtteanX::SPARQL::Constants;
@@ -350,7 +351,7 @@ package Attean::CastExpression 0.030 {
 	}
 }
 
-package Attean::ExistsExpression 0.030 {
+package Attean::ExistsExpression 0.031 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -402,7 +403,7 @@ package Attean::ExistsExpression 0.030 {
 	}
 }
 
-package Attean::ExistsPlanExpression 0.030 {
+package Attean::ExistsPlanExpression 0.031 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	use namespace::clean;
@@ -467,7 +468,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2020 Gregory Todd Williams.
+Copyright (c) 2014--2022 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
